<?php
/**
 * Present News functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Present News
 */

add_theme_support( 'title-tag' );

add_theme_support( 'automatic-feed-links' );

add_theme_support( 'register_block_style' );

add_theme_support( 'register_block_pattern' );

add_theme_support( 'responsive-embeds' );

add_theme_support( 'wp-block-styles' );

add_theme_support( 'align-wide' );

add_theme_support(
	'html5',
	array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'style',
		'script',
	)
);

add_theme_support(
	'custom-logo',
	array(
		'height'      => 250,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
	)
);

if ( ! function_exists( 'present_news_setup' ) ) :
	function present_news_setup() {
		/*
		* Make child theme available for translation.
		* Translations can be filed in the /languages/ directory.
		*/
		load_child_theme_textdomain( 'present-news', get_stylesheet_directory() . '/languages' );
	}
endif;
add_action( 'after_setup_theme', 'present_news_setup' );

if ( ! function_exists( 'present_news_enqueue_styles' ) ) :
	/**
	 * Enqueue scripts and styles.
	 */
	function present_news_enqueue_styles() {
		$parenthandle = 'current-news-style';
		$theme        = wp_get_theme();

		wp_enqueue_style(
			$parenthandle,
			get_template_directory_uri() . '/style.css',
			array(
				'current-news-fonts',
				'current-news-slick-style',
				'current-news-fontawesome-style',
				'current-news-blocks-style',
			),
			$theme->parent()->get( 'Version' )
		);

		wp_enqueue_style(
			'present-news-style',
			get_stylesheet_uri(),
			array( $parenthandle ),
			$theme->get( 'Version' )
		);

	}

endif;

add_action( 'wp_enqueue_scripts', 'present_news_enqueue_styles' );

function present_news_custom_control_scripts() {
	?>
	<style type="text/css">
		li#accordion-section-current_news_recent_posts_section,
		li#accordion-section-current-news {
			display: none !important;
		}
	</style>
	<?php
}
add_action( 'customize_controls_enqueue_scripts', 'present_news_custom_control_scripts' );

function present_news_load_custom_wp_admin_style() {
	?>
	<style type="text/css">

		.ocdi p.demo-data-download-link {
			display: none !important;
		}

	</style>

	<?php
}
add_action( 'admin_enqueue_scripts', 'present_news_load_custom_wp_admin_style' );

// Style for demo data download link
function present_news_admin_panel_demo_data_download_link() {
	?>
	<style type="text/css">
		p.present-news-demo-data {
			font-size: 16px;
			font-weight: 700;
			display: inline-block;
			border: 0.5px solid #dfdfdf;
			padding: 8px;
			background: #ffff;
		}
	</style>
	<?php
}
add_action( 'admin_enqueue_scripts', 'present_news_admin_panel_demo_data_download_link' );

 /**
 * Set up the WordPress core custom header feature.
 *
 * @uses present_news_header_style()
 */
 function present_news_custom_header_setup() {
 	add_theme_support(
 		'custom-header',
 		apply_filters(
 			'current_news_custom_header_args',
 			array(
 				'default-image'      => '',
 				'default-text-color' => '000000',
 				'width'              => 1000,
 				'height'             => 250,
 				'flex-height'        => true,
 				'wp-head-callback'   => 'current_news_header_style',
 			)
 		)
 	);
 }
 add_action( 'after_setup_theme', 'present_news_custom_header_setup' );

 function present_news_header_text_style() {
 	?>
 	<style type="text/css">

 		/* Site title */
 		.site-title a{
 			color: #<?php echo esc_attr( get_header_textcolor() ); ?>;
 		}
 		/* End Site title */

 	</style>

 	<?php
 }
 add_action( 'wp_head', 'present_news_header_text_style' );

// Widgets.
 require get_theme_file_path() . '/inc/widgets/posts-carousel-widget.php';

 // upgrade to pro.
require get_theme_file_path() . '/inc/upgrade-to-pro/class-customize.php';

// One Click Demo Import after import setup.
 if ( class_exists( 'OCDI_Plugin' ) ) {
 	require get_theme_file_path() . '/inc/demo-import.php';
 }
